@@ -6,7 +6,6 @@ import click
 import traceback
 import json
 
-from ladybug.color import Color
 from honeybee_vtk.model import Model
 from honeybee_vtk.vtkjs.schema import SensorGridOptions, DisplayMode
 from honeybee_vtk.types import ImageTypes, RadialSensor
@@ -216,7 +215,7 @@ def model_images(
     show_default=True
 )
 @click.option(
-    '--grids-filter', '-gf', type=str, default='*', show_default=True, multiple=True,
+    '--grid-filter', '-gf', type=str, default='*', show_default=True, multiple=True,
     help='A regex pattern as a string to filter the grids. Defaults to *'
     ' which will export all the grids.'
 )
@@ -248,17 +247,12 @@ def model_images(
     '--text-bold/--text-normal', is_flag=True, default=False, show_default=True,
     help='Set the text to be bold for the text that will added to the image of a grid.'
 )
-@click.option(
-    '--grid-colors', '-gc', type=(int, int, int), default=None, show_default=True,
-    multiple=True, help='A list of RGB values for colors to be used to color the grids.'
-    ' this is useful when you do not want to use the ladyug colorset defined in the'
-    ' config.'
-)
+
 def grid_images(
         hbjson_file, folder, image_type, image_width, image_height,
         background_color, grid_options, grid_display_mode,
-        config, grids_filter, full_match, text_content, text_height, text_color,
-        text_position, text_bold, grid_colors):
+        config, grid_filter, full_match, text_content, text_height, text_color,
+        text_position, text_bold):
     """Export images of the grids for the Honeybee Model created from the HBJSON file.
 
     \b
@@ -308,18 +302,14 @@ def grid_images(
                                position=text_position, bold=text_bold)\
             if text_content else None
 
-        if grid_colors:
-            grid_colors = [Color(r, g, b) for r, g, b in grid_colors]
-
         output = model.to_grid_images(config=config, folder=folder,
-                                      grids_filter=grids_filter, full_match=full_match,
+                                      grid_filter=grid_filter, full_match=full_match,
                                       grid_display_mode=grid_display_mode,
                                       background_color=background_color,
                                       image_type=image_type,
                                       image_width=image_width,
                                       image_height=image_height,
-                                      text_actor=text_actor,
-                                      grid_colors=grid_colors)
+                                      text_actor=text_actor)
 
     except Exception:
         traceback.print_exc()
@@ -347,7 +337,7 @@ def grid_images(
                     dir_okay=True), default='.', show_default=True
 )
 @click.option(
-    '--grids-filter', '-gf', type=str, default='*', show_default=True, multiple=True,
+    '--grid-filter', '-gf', type=str, default='*', show_default=True, multiple=True,
     help='A regex pattern as a string to filter the grids. Defaults to *'
     ' which will export all the grids.'
 )
@@ -372,7 +362,7 @@ def grid_images(
 )
 def time_step_images(
         hbjson_file, config, time_step_file, folder,
-        grids_filter, full_match, label, image_width, image_height):
+        grid_filter, full_match, label, image_width, image_height):
     """Export images of the grids for the Honeybee Model created from the HBJSON file.
 
     \b
@@ -396,7 +386,7 @@ def time_step_images(
         for time_step_data in data.time_step_data:
             export_time_step_images(hbjson_file, config, time_step_data,
                                     target_folder=folder.as_posix(),
-                                    grids_filter=grids_filter,
+                                    grid_filter=grid_filter,
                                     full_match=full_match,
                                     label_images=label,
                                     image_width=image_width,
